@@ -1,5 +1,8 @@
 module Dotenv
+  # This class inherits from Hash and represents the environemnt into which
+  # Dotenv will load key value pairs from a file.
   class Environment < Hash
+    attr_reader :filename
 
     def initialize(filename)
       @filename = filename
@@ -15,11 +18,11 @@ module Dotenv
     end
 
     def apply
-      each { |k,v| ENV[k] ||= v }
+      each { |k, v| ENV[k] ||= v }
     end
 
     def apply!
-      each { |k,v| ENV[k] = v }
+      each { |k, v| ENV[k] = v }
     end
   end
 end
