@@ -1,7 +1,7 @@
-desc 'Load environment settings from .env'
+desc "Load environment settings from .env"
 task :dotenv do
-  require 'dotenv'
+  require "dotenv"
   Dotenv.load
 end
 
-task :environment => :dotenv
\ No newline at end of file
+task :environment => :dotenv
